quscope.qml.image\_encoding
===========================

.. automodule:: quscope.qml.image_encoding

   
   .. rubric:: Functions

   .. autosummary::
   
      encode_image_quantum
   
   .. rubric:: Classes

   .. autosummary::
   
      QuantumImageEncoder
   